Task: QA-ZRE Relation Extraction
=================================
Description: Zero Shot relation extraction task implemented as part of the DecaNLP task. More info on the dataset can be found here:http://nlp.cs.washington.edu/zeroshot/

Tags: #qazre, #All, #decanlp

